==> mysocials-ui_1.0-3.tar.gz: mysocials-ui-1.0/translations/mysocials_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="17"/>
        <source>MySocials</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="106"/>
        <source>&amp;Friends</source>
        <translation>&amp;Друзья</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="113"/>
        <source>&amp;Messages</source>
        <translation>&amp;Сообщения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="120"/>
        <source>&amp;Albums</source>
        <translation>&amp;Альбомы</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="127"/>
        <source>&amp;More</source>
        <translation>&amp;Другое</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="140"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <source>Full screen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="146"/>
        <source>&amp;Upload images</source>
        <translation>&amp;Загрузить фотографии</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="151"/>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="161"/>
        <source>Accounts</source>
        <translation>Настройка учетных записей</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="163"/>
        <source>Network</source>
        <translation>Настройка сети</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="165"/>
        <source>Program settings</source>
        <translation>Настройка приложения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="170"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="173"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="176"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="308"/>
        <location filename="../src/mainwindow.cpp" line="312"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>/help.html</source>
        <translation>/help_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Help - %1</source>
        <translation>Справка - %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="413"/>
        <source>/about.html</source>
        <translation>/about_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="414"/>
        <source>About - %1</source>
        <translation>О программе - %1</translation>
    </message>
</context>
<context>
    <name>Profile</name>
    <message>
        <location filename="../src/ui/profile.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="22"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="29"/>
        <source>Surname</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="36"/>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="43"/>
        <source>Email</source>
        <translation>Электронная почта</translation>
    </message>
</context>
<context>
    <name>UIApplicationSettings</name>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="46"/>
        <source>Enable window rotation</source>
        <translation>Включить поворот окна</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="53"/>
        <source>Enable multi panel mode</source>
        <translation>Включить многопанельный режим</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="60"/>
        <source>Clear cache</source>
        <translation>Очистить кэш</translation>
    </message>
</context>
</TS>

==> mysocials-ui_1.0.3-5.tar.gz: mysocials-ui-1.0.3/translations/mysocials_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="17"/>
        <source>MySocials</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="105"/>
        <source>&amp;Friends</source>
        <translation>&amp;Друзья</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="112"/>
        <source>&amp;Messages</source>
        <translation>&amp;Сообщения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>&amp;Albums</source>
        <translation>&amp;Альбомы</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="126"/>
        <source>&amp;More</source>
        <translation>&amp;Другое</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="139"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="140"/>
        <source>Full screen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>&amp;Upload images</source>
        <translation>&amp;Загрузить фотографии</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="150"/>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="160"/>
        <source>Accounts</source>
        <translation>Настройка учетных записей</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="162"/>
        <source>Network</source>
        <translation>Настройка сети</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="164"/>
        <source>Program settings</source>
        <translation>Настройка приложения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="169"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="172"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="175"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="320"/>
        <location filename="../src/mainwindow.cpp" line="324"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <location filename="../src/mainwindow.cpp" line="375"/>
        <source>Notification</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <source>Your message was saved in Drafts.</source>
        <translation>Ваше сообщение сохранено в Черновиках.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="438"/>
        <source>Your message was successfully sent.</source>
        <translation>Ваше сообщение успешно отправлено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Message was deleted.</source>
        <translation>Сообщение удалено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="474"/>
        <source>/help.html</source>
        <translation>/help_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="475"/>
        <source>Help - %1</source>
        <translation>Справка - %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="492"/>
        <source>/about.html</source>
        <translation>/about_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>About - %1</source>
        <translation>О программе - %1</translation>
    </message>
</context>
<context>
    <name>Profile</name>
    <message>
        <location filename="../src/ui/profile.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="22"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="29"/>
        <source>Surname</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="36"/>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="43"/>
        <source>Email</source>
        <translation>Электронная почта</translation>
    </message>
</context>
<context>
    <name>UIApplicationSettings</name>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="46"/>
        <source>Enable window rotation</source>
        <translation>Включить поворот окна</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="53"/>
        <source>Enable multi panel mode</source>
        <translation>Включить многопанельный режим</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="60"/>
        <source>Clear cache</source>
        <translation>Очистить кэш</translation>
    </message>
</context>
</TS>
